@@ -263,7 +263,7 @@ for opt in options:
 		texfile_nm = a
 	elif o == '--enc':
 		enc_nm = a
-	elif o == '--ly' or o == '-':
+	elif o == '--ly' or o == '-l':
 		lyfile_nm = a
 	elif o== '--help' or o == '-h':
 		help()
@@ -280,7 +280,7 @@ for opt in options:
 base = re.sub ('.tex$', '', texfile_nm)
 
 for filenm in files:
-	(g,m, deps) =  parse_logfile (filenm)
+	(g, m, deps) = parse_logfile (filenm)
 	cs = tfm_checksum (re.sub ('.log$', '.tfm', filenm))
 	afm = open (afmfile_nm, 'w')
 
@@ -291,7 +291,7 @@ for filenm in files:
 	del g['DesignSize']
 	
 	write_afm_metric (afm, g, m)
-	
+
 	write_tex_defs (open (texfile_nm, 'w'), g, m)
 	enc_name = 'FetaEncoding'
 	if re.search ('parmesan', filenm) :
@@ -299,12 +299,14 @@ for filenm in files:
 	elif re.search ('feta-brace', filenm) :
 		enc_name = 'FetaBraceEncoding'
 
-		
 	write_ps_encoding (enc_name, open (enc_nm, 'w'), g, m)
 
-	write_deps (open (depfile_nm, 'wb'), deps, [base + '.dvi', base + '.pfa', base + '.pfb',  texfile_nm, afmfile_nm])
-	if lyfile_nm != '':
-		write_fontlist(open (lyfile_nm, 'w'), g, m)
+	if depfile_nm:
+		write_deps (open (depfile_nm, 'wb'), deps,
+			    [base + '.dvi', base + '.pfa', base + '.pfb',
+			     texfile_nm, afmfile_nm])
+	if lyfile_nm:
+		write_fontlist (open (lyfile_nm, 'w'), g, m)
 
 
 
