@@ -8,7 +8,7 @@
 
 #include <math.h>
 
-#include "config.h"
+#include "config.hh"
 #include "warn.hh"
 #include "libc-extension.hh"
 #include "bezier.hh"
@@ -59,6 +59,9 @@ translate (Array<Offset>* array, Offset o)
   Formula of the bezier 3-spline
 
   sum_{j=0}^3 (3 over j) z_j (1-t)^ (3-j)  t^j
+
+
+  A is the axis of X coordinate.
  */
 
 Real
