@@ -33,10 +33,10 @@ Font_size_engraver::acknowledge_grob (Grob_info gi)
   /*
     We only want to process a grob once.
    */
-  if (gi.origin_trans_->get_parent_context () != get_parent_context ())
+  if (gi.origin_trans_->context () != context ())
     return ;
   
-  if (is_number (sz) && ly_scm2double (sz))
+  if (ly_c_number_p (sz) && ly_scm2double (sz))
     {
       Real font_size = ly_scm2double (sz);
       
