@@ -1,10 +1,9 @@
 /*
   ly-module.cc --  implement guile module stuff.
-  
-  source file of the GNU LilyPond music typesetter
-  
-  (c) 2002--2004 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 
+  source file of the GNU LilyPond music typesetter
+
+  (c) 2002--2004 Han-Wen Nienhuys <hanwen@cs.uu.nl>
 */
 
 #include "main.hh"
@@ -29,16 +28,13 @@ ly_make_anonymous_module (bool safe)
   SCM mod = SCM_EOL;
   if (!safe)
     {
-      
       String s = "*anonymous-ly-" + to_string (module_count++) +  "*";
       mod = scm_c_define_module (s.to_str0 (), ly_init_anonymous_module, 0);
-
       ly_use_module (mod, global_lily_module);
     }
   else
     {
       SCM proc = ly_scheme_function ("make-safe-lilypond-module");
-
       mod = scm_call_0 (proc);
     }
   return mod;
@@ -71,12 +67,21 @@ ly_module_define (void *closure, SCM key, SCM val, SCM result)
 /* Ugh signature of scm_internal_hash_fold () is inaccurate.  */
 typedef SCM (*Hash_cl_func)();
 
-void
-ly_import_module (SCM dest, SCM src)
+/*
+  Check me. This is NOT an actual import. It just copies the
+  definitions.
+
+  If a variable in changed in SRC, we DEST doesn't see the
+  definitions.
+ */
+LY_DEFINE (ly_import_module, "ly:import-module",
+	   2, 0, 0, (SCM dest, SCM src),
+	   "Import all bindings from module SRC into DEST.")
 {
   SCM_VALIDATE_MODULE (1, src);
   scm_internal_hash_fold ((Hash_cl_func) &ly_module_define, (void*) dest,
 			  SCM_EOL, SCM_MODULE_OBARRAY (src));
+  return SCM_UNSPECIFIED;
 }
 
 static SCM
@@ -104,9 +109,9 @@ entry_to_alist (void *closure, SCM key, SCM val, SCM result)
   return scm_cons (scm_cons (key, scm_variable_ref (val)), result);
 }
 
-LY_DEFINE(ly_module_to_alist, "ly:module->alist",
-	  1,0,0, (SCM mod),
-	  "Dump the contents of  module @var{mod} as an alist.")
+LY_DEFINE (ly_module2alist, "ly:module->alist",
+	   1, 0, 0, (SCM mod),
+	   "Dump the contents of  module @var{mod} as an alist.")
 {
   SCM_VALIDATE_MODULE (1, mod);
   SCM obarr= SCM_MODULE_OBARRAY (mod);
@@ -125,28 +130,27 @@ ly_module_lookup (SCM module, SCM sym)
 #undef FUNC_NAME
 }
 
-/*
-  Lookup SYM in a list of modules, which do not have to be related.
-  Return the first instance.
- */
-LY_DEFINE(ly_modules_lookup, "ly:modules-lookup",
-	  2, 1, 0,
-	  (SCM modules, SCM sym, SCM def),
-	  "Lookup @var{sym} in the list @var{modules}, returning the "
-	  "first occurence. If not found, return @var{default}, or @code{#f}.")
+/* Lookup SYM in a list of modules, which do not have to be related.
+   Return the first instance. */
+LY_DEFINE (ly_modules_lookup, "ly:modules-lookup",
+	   2, 1, 0,
+	   (SCM modules, SCM sym, SCM def),
+	   "Lookup @var{sym} in the list @var{modules}, "
+	   "returning the first occurence.  "
+	   "If not found, return @var{default}, or @code{#f}.")
 {
   for (SCM s = modules; ly_c_pair_p (s); s = ly_cdr (s))
     {
       SCM mod = ly_car (s);      
-      SCM v = scm_sym2var (sym, scm_module_lookup_closure (mod), SCM_UNDEFINED);
-      if (SCM_VARIABLEP(v)  && SCM_VARIABLE_REF(v) != SCM_UNDEFINED)
+      SCM v = scm_sym2var (sym, scm_module_lookup_closure (mod),
+			   SCM_UNDEFINED);
+      if (SCM_VARIABLEP(v) && SCM_VARIABLE_REF(v) != SCM_UNDEFINED)
 	return SCM_VARIABLE_REF(v);
     }
 
   if (def != SCM_UNDEFINED)
     return def;
-  else
-    return SCM_BOOL_F;
+  return SCM_BOOL_F;
 }
 
 void
