@@ -12,7 +12,7 @@
 #include <locale.h>
 #include <string.h>
 
-#include "config.h"
+#include "config.hh"
 
 #if HAVE_GETTEXT
 #include <libintl.h>
@@ -140,12 +140,12 @@ static void
 dir_info (FILE *out)
 {
   fputs ("\n", out);
-  fprintf (out, "lilypond_datadir: `%s'\n", LILYPOND_DATADIR);
-  fprintf (out, "local_lilypond_datadir: `%s'\n", LOCAL_LILYPOND_DATADIR);
-  fprintf (out, "localedir: `%s'\n", LOCALEDIR);
+  fprintf (out, "LILYPOND_DATADIR=\"%s\"\n", LILYPOND_DATADIR);
+  fprintf (out, "LOCAL_LILYPOND_DATADIR=\%s\"\n", LOCAL_LILYPOND_DATADIR);
+  fprintf (out, "LOCALEDIR=\"%s\"\n", LOCALEDIR);
 
   char *lilypond_prefix = getenv ("LILYPONDPREFIX");
-  fprintf (out, "LILYPONDPREFIX: `%s'\n",
+  fprintf (out, "LILYPONDPREFIX=\"%s\"\n",
 	   (lilypond_prefix ? lilypond_prefix : ""));
 }
 
@@ -226,7 +226,7 @@ setup_paths ()
 #if !KPATHSEA
 	/* Urg: GNU make's $ (word) index starts at 1 */
 	int i  = 1;
-	while (global_path.try_add (p + to_string (".") + to_string (i)))
+	while (global_path.try_append (p + to_string (".") + to_string (i)))
 	  i++;
 #endif
       }
