@@ -52,6 +52,18 @@ Stem::set_beaming (Grob *me, int beam_count, Direction d)
   index_set_cell (pair, d, lst);
 }
 
+int
+Stem::get_beaming (Grob *me, Direction d)
+{
+  SCM pair = me->get_property ("beaming");
+  if (!ly_c_pair_p (pair))
+    return 0;
+
+  SCM lst = index_get_cell (pair, d);
+  return scm_ilength (lst);
+}
+
+
 Interval
 Stem::head_positions (Grob *me)
 {
@@ -154,7 +166,11 @@ Stem::last_head (Grob *me)
   return 0;  
 }
 
-/* START is part where stem reaches `last' head.  */
+/* START is part where stem reaches `last' head.
+
+This function returns a drul with (bottom-head, top-head). 
+
+*/
 Drul_array<Grob*>
 Stem::extremal_heads (Grob *me)
 {
@@ -377,7 +393,7 @@ Stem::position_noteheads (Grob *me)
     Pointer_group_interface__extract_grobs (me, (Grob*) 0, "note-heads");
 
   heads.sort (compare_position);
-  Direction dir =get_direction (me);
+  Direction dir = get_direction (me);
 
   if (dir < 0)
     heads.reverse ();
@@ -483,6 +499,16 @@ Stem::height (SCM smob, SCM ax)
   Grob *me = unsmob_grob (smob);
   assert (a == Y_AXIS);
 
+  /*
+    ugh. - this dependency should be automatic.
+  */
+  Grob *beam= get_beam (me);
+  if (beam)
+    {
+      Beam::after_line_breaking (beam->self_scm ());
+    }
+  
+
   SCM mol = me->get_uncached_stencil ();
   Interval iv;
   if (mol != SCM_EOL)
