@@ -109,7 +109,7 @@ Volta_repeat_iterator::add_repeat_command (SCM what)
 
   Context * where = get_outlet ()->where_defined (reps);
   if (where
-      && current_reps == SCM_EOL || is_pair (current_reps))
+      && current_reps == SCM_EOL || ly_c_pair_p (current_reps))
     {
       current_reps = scm_cons (what, current_reps);
       where->internal_set_property (reps, current_reps);
