@@ -563,8 +563,6 @@
 	(print-function . ,Text_item::print)
 	(Y-offset-callbacks . (,Side_position_interface::aligned_side))	
 	(direction . 1)
-	(breakable . #t)
-	(break-visibility . ,end-of-line-invisible)
 	(padding . 0.8)
 	(meta . ((interfaces . (text-interface side-position-interface font-interface metronome-mark-interface item-interface))))
 	))
@@ -700,32 +698,20 @@
 	(before-line-breaking-callback . ,Paper_column::before_line_breaking)
 	(X-extent-callback . ,Axis_group_interface::group_extent_callback)
 
-;ppp	        (print-function . ,Paper_column::print) (font-name . "cmr8") (Y-extent-callback . #f)
+;	        (print-function . ,Paper_column::print) (font-name . "ecrm8") (Y-extent-callback . #f)
 	(meta . ((interfaces . (paper-column-interface axis-group-interface spaceable-grob-interface item-interface ))))
 	))
 
     (PhrasingSlur
      . (
-	(print-function . ,Slur::print)
+	(print-function . ,New_slur::print)
 	(thickness . 1.2)		
 	(spacing-procedure . ,Spanner::set_spacing_rods)		
 	(minimum-length . 1.5)
-	(after-line-breaking-callback . ,Slur::after_line_breaking)
-	(extremity-function . ,calc-slur-extremity)
-	(extremity-offset-alist . ,default-phrasing-slur-extremity-offset-alist)
-	(de-uglify-parameters . (1.5  0.8  -2.0))
-	(Y-extent-callback . ,Slur::height)
+	(after-line-breaking-callback . ,New_slur::after_line_breaking)
+	(Y-extent-callback . ,New_slur::height)
 	(height-limit . 2.0)
 	(ratio . 0.333)
-	(beautiful . 0.5)
-	(y-free . 0.75)
-	(attachment . (#f . #f))
-	(attachment-offset . ((0 . 0) . (0 . 0)))
-	(slope-limit . 0.8)
-	(details . ((force-blowfit . 0.5)
-		    (bezier-pct-c0 . -0.2) (bezier-pct-c3 . 0.000006)
-		    (bezier-pct-out-max . 0.8) (bezier-pct-in-max . 1.2)
-		    (bezier-area-steps . 1.0)))
 	(meta . ((interfaces . (slur-interface spanner-interface))))
 	))
 
@@ -736,7 +722,7 @@
 	(before-line-breaking-callback . ,Paper_column::before_line_breaking)
 	(breakable . #t)
 	;; debugging stuff: print column number.
-;	(print-function . ,Paper_column::print) (font-name . "cmr8")	(Y-extent-callback . #f)
+;	(print-function . ,Paper_column::print) (font-name . "ecrm8")	(Y-extent-callback . #f)
 
 
 	(meta .  ((interfaces . (paper-column-interface axis-group-interface spaceable-grob-interface item-interface ))))
@@ -830,26 +816,15 @@
 
     (Slur
      . (
-	(print-function . ,Slur::print)
+	(print-function . ,New_slur::print)
 	(thickness . 1.2)		
 	(spacing-procedure . ,Spanner::set_spacing_rods)		
 	(minimum-length . 1.5)
-	(after-line-breaking-callback . ,Slur::after_line_breaking)
-	(extremity-function . ,calc-slur-extremity)
-	(extremity-offset-alist . ,default-slur-extremity-offset-alist)
-	(de-uglify-parameters . (1.5  0.8  -2.0))
-	(Y-extent-callback . ,Slur::height)
+	(after-line-breaking-callback . ,New_slur::after_line_breaking)
+	(Y-extent-callback . ,New_slur::height)
+					; Slur::height)
 	(height-limit . 2.0)
-	(ratio . 0.333)
-	(beautiful . 0.5)
-	(y-free . 0.75)
-	(attachment . (#f . #f))
-	(attachment-offset . ((0 . 0) . (0 . 0)))
-	(slope-limit . 0.8)
-	(details . ((force-blowfit . 0.5)
-		    (bezier-pct-c0 . -0.2) (bezier-pct-c3 . 0.000006)
-		    (bezier-pct-out-max . 0.8) (bezier-pct-in-max . 1.2)
-		    (bezier-area-steps . 1.0)))
+	(ratio . 0.25)
 	(meta . ((interfaces . (slur-interface spanner-interface))))
 	))
 
