@@ -26,8 +26,8 @@ TODO:
 
 import __main__
 import glob
+import stat
 import string
-
 ################################################################
 # Users of python modules should include this snippet
 # and customize variables below.
@@ -298,7 +298,11 @@ output = {
 
 PREAMBLE_LY = r'''%%%% Generated by %(program_name)s
 %%%% Options: [%(option_string)s]
-#(define toplevel-score-handler ly:parser-print-score)
+#(set! toplevel-score-handler ly:parser-print-score)
+#(set! toplevel-music-handler (lambda (p m)
+			       (ly:parser-print-score
+				p (ly:music-scorify m))
+			    ))
 %(preamble_string)s
 \paper {%(paper_string)s
 }
@@ -347,9 +351,7 @@ def compose_ly (code, options):
 	if QUOTE in options and LINEWIDTH in options:
 		options.remove (LINEWIDTH)
 
-	m = re.search (r'''\\(header|score)''', code)
-	if not m and (not options \
-		      or not NOFRAGMENT in options or FRAGMENT in options):
+	if FRAGMENT in options:
 		if RAGGEDRIGHT not in options:
 			options.append (RAGGEDRIGHT)
 		body = FRAGMENT_LY
@@ -541,19 +543,25 @@ class Lilypond_snippet (Snippet):
 	def write_ly (self):
 		outf = open (self.basename () + '.ly', 'w')
 		outf.write (self.full_ly ())
+		
+		open (self.basename() + '.txt', 'w').write("image of music")
+		
 
 	def is_outdated (self):
 		base = self.basename ()
 
-		found = os.path.exists (base + '.ly') and \
-			os.path.exists (base + '.tex')
+		tex_file = '%s.tex' % base
+		ly_file = '%s.ly' % base
+		ok = os.path.exists (ly_file) and os.path.exists (tex_file)\
+		     and os.stat (tex_file)[stat.ST_SIZE] \
+		     and open (tex_file).readlines ()[-1][1:-1] \
+		     == 'lilypondend'
 
 		if format == HTML or format == TEXINFO:
-			found = found and (os.path.exists (base + '.png')
-					   or glob.glob (base + '-page*.png'))
+			ok = ok and (os.path.exists (base + '.png')
+				     or glob.glob (base + '-page*.png'))
 			
-		if found and (use_hash_p \
-			or self.ly () == open (base + '.ly').read ()):
+		if ok and (use_hash_p or self.ly () == open (ly_file).read ()):
 			# TODO: something smart with target formats
 			# (ps, png) and m/ctimes
 			return None
@@ -608,6 +616,7 @@ class Lilypond_snippet (Snippet):
 		str = output[TEXINFO][BEFORE] % vars ()
 		for image in self.get_images ():
 			base, ext = os.path.splitext (image)
+			
 			# URG, makeinfo implicitely prepends dot to ext
 			# specifying no extension is most robust
 			ext = ''
@@ -798,6 +807,7 @@ def process_snippets (cmd, snippets):
 			if not os.path.exists (i + '.eps') and os.path.exists (i + '.tex'):
 				to_eps (i)
 				ly.make_ps_images (i + '.eps', resolution=110)
+				
 #			elif os.path.exists (i + '.ps'):
 #				ly.make_ps_images (i + '.ps', resolution=110)
 
